==> nextcloud-25.0.8.tgz: nextcloud/apps/serverinfo/l10n/de_DE.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informationen zur CPU nicht verfügbar",
    "Load average: {cpu} (last minute)" : "Durchschnittliche Last: {cpu} (letzte Minute)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Gesamt: {memTotalBytes}/Aktuelle Nutzung: {memUsageBytes}",
    "RAM info not available" : "Informationen zum RAM nicht verfügbar",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Gesamt: {swapTotalBytes}/Aktuelle Nutzung: {swapUsageBytes}",
    "SWAP info not available" : "Informationen zum SWAP nicht verfügbar",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
    "System" : "System",
    "Monitoring" : "Information",
    "Monitoring app with useful server information" : "Monitoring-App mit nützlichen Serverinformationen",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zeigt nützliche Informationen des Servers an wie z.B. CPU-Last, Arbeitsspeicherauslastung, Massenspeicherauslastung, Anzahl der Benutzer, usw.",
    "Operating System:" : "Betriebssystem:",
    "CPU:" : "Prozessor:",
    "Unknown Processor" : "Unbekannter Prozessor",
    "Memory:" : "Speicher:",
    "Server time:" : "Server-Zeit:",
    "Uptime:" : "Betriebszeit:",
    "Temperature" : "Temperatur",
    "Load" : "Auslastung",
    "Memory" : "Speicher",
    "Disk" : "Festplatte",
    "Mount:" : "Mount:",
    "Filesystem:" : "Dateisystem:",
    "Size:" : "Größe:",
    "Available:" : "Verfügbar:",
    "Used:" : "Verwendet:",
    "You will get a notification once one of your disks is nearly full." : "Sie erhalten eine Benachrichtigung, sobald eines Ihrer Speichermedien fast voll ist.",
    "Files:" : "Dateien:",
    "Storages:" : "Speicher:",
    "Free Space:" : "Freier Speicherplatz:",
    "Network" : "Netzwerk",
    "Hostname:" : "Hostname:",
    "DNS:" : "DNS:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Geschwindigkeit:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktive Benutzer",
    "Total users:" : "Benutzer gesamt:",
    "24 hours:" : "24 Stunden:",
    "1 hour:" : "1 Stunde:",
    "5 mins:" : "5 Minuten:",
    "Shares" : "Freigaben",
    "Users:" : "Benutzer:",
    "Groups:" : "Gruppen:",
    "Links:" : "Links:",
    "Emails:" : "E-Mails:",
    "Federated sent:" : "Federated gesendet:",
    "Federated received:" : "Federated empfangen:",
    "Talk conversations:" : "Talk-Unterhaltungen:",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory limit:" : "Speicherlimit:",
    "Max execution time:" : "Maximale Ausführungszeit:",
    "Upload max size:" : "Maximale Größe zum Hochladen:",
    "OPcache Revalidate Frequency:" : "OPcache-Revalidierungshäufigkeit:",
    "Extensions:" : "Erweiterungen:",
    "Unable to list extensions" : "Erweiterungen können nicht aufgelistet werden",
    "Database" : "Datenbank",
    "Type:" : "Art:",
    "External monitoring tool" : "Externes Überwachungsprogramm",
    "You can connect an external monitoring tool by using this end point:" : "Durch Verwendung des folgenden Zugangspunktes kann ein externes Überwachungsprogramm verwendet werden: ",
    "Copy" : "Kopieren",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Wenn Sie \"?format=json\" am Ende der URL anhängen, erhalten Sie das Ergebnis in JSON.",
    "To use an access token, please generate one then set it using the following command:" : "Um ein Zugriffstoken zu verwenden, generieren Sie bitte eines und legen Sie es mit dem folgenden Befehl fest:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Übergeben Sie dann das Token mit dem Header \"NC-Token\" durch Aufrufen der obigen URL."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.12p1.tgz: nextcloud/apps/serverinfo/l10n/de_DE.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informationen zur CPU nicht verfügbar",
    "Load average: {cpu} (last minute)" : "Durchschnittliche Last: {cpu} (letzte Minute)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Gesamt: {memTotalBytes}/Aktuelle Nutzung: {memUsageBytes}",
    "RAM info not available" : "Informationen zum RAM nicht verfügbar",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Gesamt: {swapTotalBytes}/Aktuelle Nutzung: {swapUsageBytes}",
    "SWAP info not available" : "Informationen zum SWAP nicht verfügbar",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
    "System" : "System",
    "Monitoring" : "Information",
    "Monitoring app with useful server information" : "Monitoring-App mit nützlichen Serverinformationen",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zeigt nützliche Informationen des Servers an wie z.B. CPU-Last, Arbeitsspeicherauslastung, Massenspeicherauslastung, Anzahl der Benutzer, usw.",
    "Operating System:" : "Betriebssystem:",
    "CPU:" : "Prozessor:",
    "Unknown Processor" : "Unbekannter Prozessor",
    "Memory:" : "Speicher:",
    "Server time:" : "Server-Zeit:",
    "Uptime:" : "Betriebszeit:",
    "Temperature" : "Temperatur",
    "Load" : "Auslastung",
    "Memory" : "Speicher",
    "Disk" : "Festplatte",
    "Mount:" : "Mount:",
    "Filesystem:" : "Dateisystem:",
    "Size:" : "Größe:",
    "Available:" : "Verfügbar:",
    "Used:" : "Verwendet:",
    "Files:" : "Dateien:",
    "Storages:" : "Speicher:",
    "Free Space:" : "Freier Speicherplatz:",
    "Network" : "Netzwerk",
    "Hostname:" : "Hostname:",
    "DNS:" : "DNS:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Geschwindigkeit:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktive Benutzer",
    "Total users:" : "Benutzer gesamt:",
    "24 hours:" : "24 Stunden:",
    "1 hour:" : "1 Stunde:",
    "5 mins:" : "5 Minuten:",
    "Shares" : "Freigaben",
    "Users:" : "Benutzer:",
    "Groups:" : "Gruppen:",
    "Links:" : "Links:",
    "Emails:" : "E-Mails:",
    "Federated sent:" : "Federated gesendet:",
    "Federated received:" : "Federated empfangen:",
    "Talk conversations:" : "Talk-Unterhaltungen:",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory limit:" : "Speicherlimit:",
    "Max execution time:" : "Maximale Ausführungszeit:",
    "Upload max size:" : "Maximale Größe zum Hochladen:",
    "OPcache Revalidate Frequency:" : "OPcache-Revalidierungshäufigkeit:",
    "Extensions:" : "Erweiterungen:",
    "Unable to list extensions" : "Erweiterungen können nicht aufgelistet werden",
    "Show phpinfo" : "phpinfo anzeigen",
    "Database" : "Datenbank",
    "Type:" : "Art:",
    "External monitoring tool" : "Externes Überwachungsprogramm",
    "You can connect an external monitoring tool by using this end point:" : "Durch Verwendung des folgenden Zugangspunktes kann ein externes Überwachungsprogramm verwendet werden: ",
    "Copy" : "Kopieren",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Wenn Sie \"?format=json\" am Ende der URL anhängen, erhalten Sie das Ergebnis in JSON.",
    "To use an access token, please generate one then set it using the following command:" : "Um ein Zugriffstoken zu verwenden, generieren Sie bitte eines und legen Sie es mit dem folgenden Befehl fest:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Übergeben Sie dann das Token mit dem Header \"NC-Token\" durch Aufrufen der obigen URL.",
    "You will get a notification once one of your disks is nearly full." : "Sie erhalten eine Benachrichtigung, sobald eines Ihrer Speichermedien fast voll ist."
},
"nplurals=2; plural=(n != 1);");
